==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLstore.h <==
// class soot.coffi.Instruction_Lstore

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3ac1b36a3dab67fd soot_coffi_Instruction__5fLstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fLstore_H_
#define _JC_soot_coffi_Instruction__5fLstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLstore$sub_refs	_jc_soot_coffi_Instruction__5fLstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fLstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$refs	_jc_soot_coffi_Instruction__5fLstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$nonrefs	_jc_soot_coffi_Instruction__5fLstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$object	_jc_soot_coffi_Instruction__5fLstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fLstore$vmethods	_jc_soot_coffi_Instruction__5fLstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLstore$vtable	_jc_soot_coffi_Instruction__5fLstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLstore$vtype	_jc_soot_coffi_Instruction__5fLstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLstore$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLstore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fLstore$vmethods	soot_coffi_Instruction__5fLstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLstore$refs {
    _jc_soot_coffi_Instruction__5fLstore$sub_refs	soot_coffi_Instruction__5fLstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs	soot_coffi_Instruction__5fLstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLstore$object {
	_jc_soot_coffi_Instruction__5fLstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLstore$vtype _jc_soot_coffi_Instruction__5fLstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLstore_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLstore.h <==
// class soot.coffi.Instruction_Lstore

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3ac1b36a3dab67fd soot_coffi_Instruction__5fLstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fLstore_H_
#define _JC_soot_coffi_Instruction__5fLstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLstore$sub_refs	_jc_soot_coffi_Instruction__5fLstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fLstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$refs	_jc_soot_coffi_Instruction__5fLstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$nonrefs	_jc_soot_coffi_Instruction__5fLstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLstore$object	_jc_soot_coffi_Instruction__5fLstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fLstore$vmethods	_jc_soot_coffi_Instruction__5fLstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLstore$vtable	_jc_soot_coffi_Instruction__5fLstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLstore$vtype	_jc_soot_coffi_Instruction__5fLstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLstore$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLstore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fLstore$vmethods	soot_coffi_Instruction__5fLstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLstore$refs {
    _jc_soot_coffi_Instruction__5fLstore$sub_refs	soot_coffi_Instruction__5fLstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fLstore$sub_nonrefs	soot_coffi_Instruction__5fLstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLstore$object {
	_jc_soot_coffi_Instruction__5fLstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLstore$vtype _jc_soot_coffi_Instruction__5fLstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLstore_H_ */
